@@ -32,7 +32,6 @@ from pyams_table.column import GetAttrColumn
 from pyams_table.interfaces import IColumn, IValues
 from pyams_template.template import template_config
 from pyams_utils.adapter import ContextRequestViewAdapter, adapter_config
-from pyams_utils.data import ObjectDataManagerMixin
 from pyams_viewlet.viewlet import viewlet_config
 from pyams_zmi.form import AdminModalAddForm, AdminModalEditForm, FormGroupSwitcher
 from pyams_zmi.helper.container import delete_container_element, switch_element_attribute
@@ -41,8 +40,8 @@ from pyams_zmi.helper.event import get_json_table_row_add_callback, \
 from pyams_zmi.interfaces import IAdminLayer
 from pyams_zmi.interfaces.table import ITableElementEditor
 from pyams_zmi.interfaces.viewlet import IToolbarViewletManager
-from pyams_zmi.table import I18nColumnMixin, IconColumn, InnerTableAdminView, JsActionColumn, \
-    NameColumn, ReorderColumn, Table, TableElementEditor, TrashColumn, \
+from pyams_zmi.table import I18nColumnMixin, IconColumn, InnerTableAdminView, NameColumn, \
+    ReorderColumn, Table, TableElementEditor, TrashColumn, VisibilityColumn, \
     get_ordered_data_attributes
 from pyams_zmi.utils import get_object_label
 
@@ -100,30 +99,13 @@ def reorder_cards_table(request):
 @adapter_config(name='visible',
                 required=(ICardsPortletSettings, IAdminLayer, CardsTable),
                 provides=IColumn)
-class CardsTableVisibleColumn(ObjectDataManagerMixin, JsActionColumn):
+class CardsTableVisibleColumn(VisibilityColumn):
     """Cards table visible column"""
 
     hint = _("Click icon to show or hide card")
 
-    href = 'MyAMS.container.switchElementAttribute'
-    modal_target = False
 
-    object_data = {
-        'ams-modules': 'container',
-        'ams-update-target': 'switch-visible-card.json',
-        'ams-attribute-name': 'visible',
-        'ams-icon-on': 'far fa-eye',
-        'ams-icon-off': 'far fa-eye-slash'
-    }
-
-    weight = 1
-
-    def get_icon_class(self, item):
-        """Icon class getter"""
-        return 'far fa-eye' if item.visible else 'far fa-eye-slash'
-
-
-@view_config(name='switch-visible-card.json',
+@view_config(name='switch-visible-item.json',
              context=ICardsPortletSettings, request_type=IPyAMSLayer,
              renderer='json', xhr=True)
 def switch_visible_card(request):
@@ -169,7 +151,10 @@ class CardsTableIllustrationColumn(IconColumn):
     icon_class = 'far fa-image text-muted'
     hint = _("Illustration")
 
-    checker = lambda self, x: bool(x.illustration and x.illustration.data)
+    @staticmethod
+    def checker(image):
+        """Column image checker"""
+        return bool(image.illustration and image.illustration.data)
 
 
 @adapter_config(name='trash',
